#  Copyright (C) 2023
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>

from typing import TypeAlias

Json: TypeAlias = dict[str, 'Json'] | list['Json'] | str | int | float | bool | None
